_G=GLOBAL
require = _G.require
rawget = _G.rawget
EQUIPSLOTS=_G.EQUIPSLOTS

--Detect is there any slot mods already enabled.
if EQUIPSLOTS.BACK ~= nil or EQUIPSLOTS.NECK ~= nil then
	return --Do nothing. Exit immediately
end

Assets =
{
	Asset("IMAGE", "images/slots5.tex"),
	Asset("ATLAS", "images/slots5.xml"),
}

EQUIPSLOTS.BACK = "back"
EQUIPSLOTS.NECK = "neck"

AddComponentPostInit("inventory", function(self,inst)
	self.numequipslots = 5
end)

--Thunder Party, Sunny, Additional Equipment, Tiny Alchemy Powers

amulets = {"amulet", "blueamulet", "purpleamulet", "orangeamulet", "greenamulet", "yellowamulet", --standard
	"blackamulet", "pinkamulet", "whiteamulet", "endiaamulet", "grayamulet", "broken_frosthammer",
	"musha_egg", "musha_egg1", "musha_egg2", "musha_egg3", "musha_egg8", "musha_eggs1", "musha_eggs2", "musha_eggs3",
	} --mods
for i,v in ipairs(amulets) do
	AddPrefabPostInit(v,function(inst)
		if inst.components.equippable then
			inst.components.equippable.equipslot = EQUIPSLOTS.NECK
		end
	end)
end

--Special tweak (Flashlight and Batteries)
AddPrefabPostInit("batteries",function(inst)
	if not inst.components.equippable then
		inst:AddComponent("equippable")
	end
	inst.components.equippable.equipslot = EQUIPSLOTS.NECK
end)

backpacks = {"backpack", "piggyback", "krampus_sack", "icepack", "mailpack", "thatchpack", "piratepack", "spicepack", "spicepack", --standard
	"seasack", --new
	"bunnyback", "wolfyback", "sunnybackpack", "frostback", } --mod
for i,v in ipairs(backpacks) do
	AddPrefabPostInit(v,function(inst)
		if inst.components.equippable then
			inst.components.equippable.equipslot = EQUIPSLOTS.BACK
		end
	end)
end

AddClassPostConstruct("screens/playerhud", function(self) 
	local oldfn = self.SetMainCharacter
	function self:SetMainCharacter(maincharacter,...)
		oldfn(self, maincharacter,...)
		if not(self.controls and self.controls.inv) then
			print("ERROR: Can't inject in screens/playerhud.")
			return
		end
		self.controls.inv:AddEquipSlot(EQUIPSLOTS.BACK, "images/slots5.xml", "back.tex")
		self.controls.inv:AddEquipSlot(EQUIPSLOTS.NECK, "images/slots5.xml", "neck.tex")
		if self.controls.inv.bg then
			self.controls.inv.bg:SetScale(1.25,1,1.25)
		end
		local bp = maincharacter.components.inventory:GetEquippedItem(EQUIPSLOTS.BACK)
		if bp and bp.components.container then
			bp.components.container:Close()
			bp.components.container:Open(maincharacter)
		end
	end
end)

--Fix resurrect behaviour:
do
	local comp_res = require "components/resurrectable"
	local comp_inv = require "components/inventory"
	
	local fix_once = nil --While hooking fix only once. May be not compatible with some mods.
	
	local old_GetEquippedItem = comp_inv.GetEquippedItem
	function comp_inv:GetEquippedItem(slot,...)
		if fix_once ~= nil then
			fix_once = nil
			local item = old_GetEquippedItem(self,EQUIPSLOTS.NECK,...)
			if item ~= nil and item.prefab == "amulet" then --We need to hook only amulet.
				return item
			end
		end
		return old_GetEquippedItem(self,slot,...)
	end
	
	--Fixing behaviour
	local old_FindClosestResurrector = comp_res.FindClosestResurrector
	function comp_res:FindClosestResurrector(...)
		fix_once = true
		return old_FindClosestResurrector(self,...)
	end

	local old_CanResurrect = comp_res.CanResurrect
	function comp_res:CanResurrect(...)
		fix_once = true
		return old_CanResurrect(self,...)
	end

	local old_DoResurrect = comp_res.DoResurrect
	function comp_res:DoResurrect(...)
		fix_once = true
		return old_DoResurrect(self,...)
	end

	--Fixing states for resurrection.
	AddSimPostInit(function()
		if not rawget(_G,"SGManager") then
			print("ERROR: Not a DS game.")
			return --Not a DS game.
		end
		for instance,_ in pairs(_G.SGManager.instances) do
			if(instance.sg.name == "wilson") then
				for k,v in pairs(instance.sg.states) do
					if(v.name == "amulet_rebirth") then
						local old_fn = v["onexit"]
						v["onexit"] = function(...) --Hook the function. Don't replace it
							fix_once = true
							return old_fn(...)
						end
						break
					end
				end
				break
			end
		end
	end)
	
end
















